@@ -138,6 +138,7 @@ CONFIG_MAPPING_NAMES = OrderedDict[str, str](
         ("encodec", "EncodecConfig"),
         ("encoder-decoder", "EncoderDecoderConfig"),
         ("eomt", "EomtConfig"),
+        ("eomt_dinov3", "EomtDinov3Config"),
         ("ernie", "ErnieConfig"),
         ("ernie4_5", "Ernie4_5Config"),
         ("ernie4_5_moe", "Ernie4_5_MoeConfig"),
@@ -145,6 +146,7 @@ CONFIG_MAPPING_NAMES = OrderedDict[str, str](
         ("esm", "EsmConfig"),
         ("evolla", "EvollaConfig"),
         ("exaone4", "Exaone4Config"),
+        ("exaone_moe", "ExaoneMoeConfig"),
         ("falcon", "FalconConfig"),
         ("falcon_h1", "FalconH1Config"),
         ("falcon_mamba", "FalconMambaConfig"),
@@ -184,6 +186,9 @@ CONFIG_MAPPING_NAMES = OrderedDict[str, str](
         ("glm_image_text", "GlmImageTextConfig"),
         ("glm_image_vision", "GlmImageVisionConfig"),
         ("glm_image_vqmodel", "GlmImageVQVAEConfig"),
+        ("glm_ocr", "GlmOcrConfig"),
+        ("glm_ocr_text", "GlmOcrTextConfig"),
+        ("glm_ocr_vision", "GlmOcrVisionConfig"),
         ("glmasr", "GlmAsrConfig"),
         ("glmasr_encoder", "GlmAsrEncoderConfig"),
         ("glpn", "GLPNConfig"),
@@ -339,6 +344,7 @@ CONFIG_MAPPING_NAMES = OrderedDict[str, str](
         ("plbart", "PLBartConfig"),
         ("poolformer", "PoolFormerConfig"),
         ("pop2piano", "Pop2PianoConfig"),
+        ("pp_doclayout_v3", "PPDocLayoutV3Config"),
         ("prompt_depth_anything", "PromptDepthAnythingConfig"),
         ("prophetnet", "ProphetNetConfig"),
         ("pvt", "PvtConfig"),
@@ -421,6 +427,7 @@ CONFIG_MAPPING_NAMES = OrderedDict[str, str](
         ("t5", "T5Config"),
         ("t5gemma", "T5GemmaConfig"),
         ("t5gemma2", "T5Gemma2Config"),
+        ("t5gemma2_encoder", "T5Gemma2EncoderConfig"),
         ("table-transformer", "TableTransformerConfig"),
         ("tapas", "TapasConfig"),
         ("textnet", "TextNetConfig"),
@@ -475,6 +482,7 @@ CONFIG_MAPPING_NAMES = OrderedDict[str, str](
         ("xmod", "XmodConfig"),
         ("yolos", "YolosConfig"),
         ("yoso", "YosoConfig"),
+        ("youtu", "YoutuConfig"),
         ("zamba", "ZambaConfig"),
         ("zamba2", "Zamba2Config"),
         ("zoedepth", "ZoeDepthConfig"),
@@ -599,6 +607,7 @@ MODEL_NAMES_MAPPING = OrderedDict[str, str](
         ("encodec", "EnCodec"),
         ("encoder-decoder", "Encoder decoder"),
         ("eomt", "EoMT"),
+        ("eomt_dinov3", "EoMT-DINOv3"),
         ("ernie", "ERNIE"),
         ("ernie4_5", "Ernie4_5"),
         ("ernie4_5_moe", "Ernie4_5_MoE"),
@@ -606,6 +615,7 @@ MODEL_NAMES_MAPPING = OrderedDict[str, str](
         ("esm", "ESM"),
         ("evolla", "Evolla"),
         ("exaone4", "EXAONE-4.0"),
+        ("exaone_moe", "EXAONE-MoE"),
         ("falcon", "Falcon"),
         ("falcon3", "Falcon3"),
         ("falcon_h1", "FalconH1"),
@@ -648,6 +658,9 @@ MODEL_NAMES_MAPPING = OrderedDict[str, str](
         ("glm_image_text", "GlmImageText"),
         ("glm_image_vision", "GlmImageVisionModel"),
         ("glm_image_vqmodel", "GlmImageVQVAE"),
+        ("glm_ocr", "Glmocr"),
+        ("glm_ocr_text", "GlmOcrText"),
+        ("glm_ocr_vision", "GlmOcrVisionModel"),
         ("glmasr", "GLM-ASR"),
         ("glmasr_encoder", "GLM-ASR Encoder"),
         ("glpn", "GLPN"),
@@ -817,6 +830,7 @@ MODEL_NAMES_MAPPING = OrderedDict[str, str](
         ("plbart", "PLBart"),
         ("poolformer", "PoolFormer"),
         ("pop2piano", "Pop2Piano"),
+        ("pp_doclayout_v3", "PPDocLayoutV3"),
         ("prompt_depth_anything", "PromptDepthAnything"),
         ("prophetnet", "ProphetNet"),
         ("pvt", "PVT"),
@@ -899,6 +913,7 @@ MODEL_NAMES_MAPPING = OrderedDict[str, str](
         ("t5", "T5"),
         ("t5gemma", "T5Gemma"),
         ("t5gemma2", "T5Gemma2"),
+        ("t5gemma2_encoder", "T5Gemma2Encoder"),
         ("t5v1.1", "T5v1.1"),
         ("table-transformer", "Table Transformer"),
         ("tapas", "TAPAS"),
@@ -959,6 +974,7 @@ MODEL_NAMES_MAPPING = OrderedDict[str, str](
         ("xmod", "X-MOD"),
         ("yolos", "YOLOS"),
         ("yoso", "YOSO"),
+        ("youtu", "Youtu"),
         ("zamba", "Zamba"),
         ("zamba2", "Zamba2"),
         ("zoedepth", "ZoeDepth"),
@@ -999,6 +1015,9 @@ SPECIAL_MODEL_TYPE_TO_MODULE_NAME = OrderedDict[str, str](
         ("glm_image_vision", "glm_image"),
         ("glm_image_vqmodel", "glm_image"),
         ("glm_image_text", "glm_image"),
+        ("glm_ocr_vision", "glm_ocr"),
+        ("glm_ocr_vqmodel", "glm_ocr"),
+        ("glm_ocr_text", "glm_ocr"),
         ("glmasr_encoder", "glmasr"),
         ("grounding-dino", "grounding_dino"),
         ("mm-grounding-dino", "mm_grounding_dino"),
@@ -1023,6 +1042,7 @@ SPECIAL_MODEL_TYPE_TO_MODULE_NAME = OrderedDict[str, str](
         ("sam3_vision_model", "sam3"),
         ("edgetam_vision_model", "edgetam"),
         ("sam_hq_vision_model", "sam_hq"),
+        ("t5gemma2_encoder", "t5gemma2"),
         ("llama4_text", "llama4"),
         ("blip_2_qformer", "blip_2"),
         ("fastspeech2_conformer_with_hifigan", "fastspeech2_conformer"),
