@@ -1,4 +1,3 @@
-# coding=utf-8
 # Copyright 2023 The HuggingFace Inc. team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,16 +13,14 @@
 # limitations under the License.
 """Autoformer model configuration"""
 
-from typing import List, Optional
-
-from ...configuration_utils import PretrainedConfig
+from ...configuration_utils import PreTrainedConfig
 from ...utils import logging
 
 
 logger = logging.get_logger(__name__)
 
 
-class AutoformerConfig(PretrainedConfig):
+class AutoformerConfig(PreTrainedConfig):
     r"""
     This is the configuration class to store the configuration of an [`AutoformerModel`]. It is used to instantiate an
     Autoformer model according to the specified arguments, defining the model architecture. Instantiating a
@@ -31,8 +28,8 @@ class AutoformerConfig(PretrainedConfig):
     [huggingface/autoformer-tourism-monthly](https://huggingface.co/huggingface/autoformer-tourism-monthly)
     architecture.
 
-    Configuration objects inherit from [`PretrainedConfig`] can be used to control the model outputs. Read the
-    documentation from [`PretrainedConfig`] for more information.
+    Configuration objects inherit from [`PreTrainedConfig`] can be used to control the model outputs. Read the
+    documentation from [`PreTrainedConfig`] for more information.
 
     Args:
         prediction_length (`int`):
@@ -137,19 +134,19 @@ class AutoformerConfig(PretrainedConfig):
 
     def __init__(
         self,
-        prediction_length: Optional[int] = None,
-        context_length: Optional[int] = None,
+        prediction_length: int | None = None,
+        context_length: int | None = None,
         distribution_output: str = "student_t",
         loss: str = "nll",
         input_size: int = 1,
-        lags_sequence: List[int] = [1, 2, 3, 4, 5, 6, 7],
+        lags_sequence: list[int] = [1, 2, 3, 4, 5, 6, 7],
         scaling: bool = True,
         num_time_features: int = 0,
         num_dynamic_real_features: int = 0,
         num_static_categorical_features: int = 0,
         num_static_real_features: int = 0,
-        cardinality: Optional[List[int]] = None,
-        embedding_dimension: Optional[List[int]] = None,
+        cardinality: list[int] | None = None,
+        embedding_dimension: list[int] | None = None,
         d_model: int = 64,
         encoder_attention_heads: int = 2,
         decoder_attention_heads: int = 2,
@@ -240,3 +237,6 @@ class AutoformerConfig(PretrainedConfig):
             + self.num_static_real_features
             + self.input_size * 2  # the log1p(abs(loc)) and log(scale) features
         )
+
+
+__all__ = ["AutoformerConfig"]
