@@ -61,12 +61,7 @@ def _cast_if_autocast_enabled(device_type, *args):
     if not torch.is_autocast_enabled():
         return args
     else:
-        # NOTE: `torch.get_autocast_dtype` is there starting from PyTorch 2.4
-        target_dtype = (
-            torch.get_autocast_dtype(device_type)
-            if hasattr(torch, "get_autocast_dtype")
-            else torch.get_autocast_gpu_dtype()
-        )
+        target_dtype = torch.get_autocast_dtype(device_type)
         return torch.amp.autocast_mode._cast(args, device_type, target_dtype)
 
 
@@ -387,12 +382,7 @@ class NemotronFlashAttention2(NemotronAttention):
         device_type = query_states.device.type if query_states.device.type != "mps" else "cpu"
         if input_dtype == torch.float32:
             if torch.is_autocast_enabled():
-                # NOTE: `torch.get_autocast_dtype` is there starting from PyTorch 2.4
-                target_dtype = (
-                    torch.get_autocast_dtype(device_type)
-                    if hasattr(torch, "get_autocast_dtype")
-                    else torch.get_autocast_gpu_dtype()
-                )
+                target_dtype = torch.get_autocast_dtype(device_type)
             # Handle the case where the model is quantized
             elif hasattr(self.config, "_is_quantized"):
                 target_dtype = self.config.dtype
