@@ -1,4 +1,3 @@
-# coding=utf-8
 # Copyright 2025 The HuggingFace Inc. team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,35 +13,16 @@
 # limitations under the License.
 """Fast Image processor class for SAM2."""
 
-from typing import Optional, Union
-
 import numpy as np
+import torch
+import torch.nn.functional as F
 
 from ...image_processing_utils import BatchFeature
-from ...image_utils import (
-    IMAGENET_DEFAULT_MEAN,
-    IMAGENET_DEFAULT_STD,
-    SizeDict,
-)
-from ...utils import (
-    TensorType,
-    is_torch_available,
-    is_vision_available,
-)
-from ...utils.import_utils import requires
+from ...image_utils import IMAGENET_DEFAULT_MEAN, IMAGENET_DEFAULT_STD, PILImageResampling, SizeDict
+from ...utils import TensorType
 from ...video_processing_utils import BaseVideoProcessor
 
 
-if is_torch_available():
-    import torch
-    from torch.nn import functional as F_t
-
-
-if is_vision_available():
-    from ...image_utils import PILImageResampling
-
-
-@requires(backends=("torchvision",))
 class Sam2VideoVideoProcessor(BaseVideoProcessor):
     resample = PILImageResampling.BILINEAR
     image_mean = IMAGENET_DEFAULT_MEAN
@@ -52,12 +32,13 @@ class Sam2VideoVideoProcessor(BaseVideoProcessor):
     do_rescale = True
     do_normalize = True
     do_convert_rgb = True
+    model_input_names = ["pixel_values"]
 
     def _preprocess(
         self,
         videos: list["torch.Tensor"],
         size: SizeDict,
-        return_tensors: Optional[Union[str, TensorType]],
+        return_tensors: str | TensorType | None,
         **kwargs,
     ) -> BatchFeature:
         original_sizes = [video.shape[-2:] for video in videos]
@@ -109,10 +90,10 @@ class Sam2VideoVideoProcessor(BaseVideoProcessor):
             if isinstance(masks[i], np.ndarray):
                 masks[i] = torch.from_numpy(masks[i])
             elif not isinstance(masks[i], torch.Tensor):
-                raise ValueError("Input masks should be a list of `torch.tensors` or a list of `np.ndarray`")
-            interpolated_mask = F_t.interpolate(masks[i], target_image_size, mode="bilinear", align_corners=False)
+                raise TypeError("Input masks should be a list of `torch.tensors` or a list of `np.ndarray`")
+            interpolated_mask = F.interpolate(masks[i], target_image_size, mode="bilinear", align_corners=False)
             interpolated_mask = interpolated_mask[..., : reshaped_input_sizes[i][0], : reshaped_input_sizes[i][1]]
-            interpolated_mask = F_t.interpolate(interpolated_mask, original_size, mode="bilinear", align_corners=False)
+            interpolated_mask = F.interpolate(interpolated_mask, original_size, mode="bilinear", align_corners=False)
             if binarize:
                 interpolated_mask = interpolated_mask > mask_threshold
             output_masks.append(interpolated_mask)
