@@ -14,6 +14,7 @@
 
 """Configuration for Backbone models"""
 
+from ...backbone_utils import BackboneConfigMixin
 from ...configuration_utils import PreTrainedConfig
 from ...utils import logging
 
@@ -21,7 +22,7 @@ from ...utils import logging
 logger = logging.get_logger(__name__)
 
 
-class TimmBackboneConfig(PreTrainedConfig):
+class TimmBackboneConfig(BackboneConfigMixin, PreTrainedConfig):
     r"""
     This is the configuration class to store the configuration for a timm backbone [`TimmBackbone`].
 
@@ -37,8 +38,6 @@ class TimmBackboneConfig(PreTrainedConfig):
             The number of input channels.
         features_only (`bool`, *optional*, defaults to `True`):
             Whether to output only the features or also the logits.
-        use_pretrained_backbone (`bool`, *optional*, defaults to `True`):
-            Whether to use a pretrained backbone.
         out_indices (`list[int]`, *optional*):
             If used as backbone, list of indices of features to output. Can be any of 0, 1, 2, etc. (depending on how
             many stages the model has). Will default to the last stage if unset.
@@ -67,19 +66,46 @@ class TimmBackboneConfig(PreTrainedConfig):
         backbone=None,
         num_channels=3,
         features_only=True,
-        use_pretrained_backbone=True,
         out_indices=None,
         freeze_batch_norm_2d=False,
+        output_stride=None,
         **kwargs,
     ):
-        super().__init__(**kwargs)
         self.backbone = backbone
         self.num_channels = num_channels
         self.features_only = features_only
-        self.use_pretrained_backbone = use_pretrained_backbone
-        self.use_timm_backbone = True
         self.out_indices = out_indices if out_indices is not None else [-1]
+        self.output_stride = output_stride
         self.freeze_batch_norm_2d = freeze_batch_norm_2d
 
+        # self._out_features = kwargs.pop("out_features", None)
+        super().__init__(**kwargs)
+
+    @property
+    def out_indices(self):
+        return self._out_indices
+
+    @out_indices.setter
+    def out_indices(self, out_indices: tuple[int, ...] | list[int]):
+        """
+        Set the out_indices attribute. This will also update the out_features attribute to match the new out_indices.
+        """
+        self._out_indices = list(out_indices) if out_indices is not None else out_indices
+        if getattr(self, "stage_names", None) is not None:
+            self.set_output_features_output_indices(out_features=None, out_indices=out_indices)
+
+    @property
+    def out_features(self):
+        return self._out_features
+
+    @out_features.setter
+    def out_features(self, out_features: list[str]):
+        """
+        Set the out_features attribute. This will also update the out_indices attribute to match the new out_features.
+        """
+        self._out_features = out_features
+        if getattr(self, "stage_names", None) is not None:
+            self.set_output_features_output_indices(out_features=out_features, out_indices=None)
+
 
 __all__ = ["TimmBackboneConfig"]
