@@ -19,10 +19,8 @@ from ...utils.import_utils import define_import_structure
 
 if TYPE_CHECKING:
     from .configuration_xlnet import *
-    from .modeling_tf_xlnet import *
     from .modeling_xlnet import *
     from .tokenization_xlnet import *
-    from .tokenization_xlnet_fast import *
 else:
     import sys
 
